/**
 * Includes a template with a dey time depending content.
 *
 * The `de_epages.shopUiGreeter` method creates a day time depending content.
 *
 * ### Examples
 * Inserts a day time depending content.
 *
 * JavaScript:
 *
 *     de_epages('.ep-dashboard-greeter-container').shopUiGreeter({
 *       header: [
 *         {start: 0, end: 10, translation: '0to10Greeting'},
 *         {start: 10, end: 12, translation: '10to12Greeting'},
 *         {start: 12, end: 14, translation: '12to14Greeting'},
 *         {start: 14, end: 18, translation: '14to18Greeting'},
 *         {start: 18, end: 24, translation: '18to24Greeting'}
 *       ],
 *       subtitle: 'GreetingSubtitle'
 *     });
 *
 * HTML:
 *
 *     <div class="ep-dashboard-greeter-container"></div>
 *
 *
 * @class jQuery.ui.shopUiGreeter
 * @extends jQuery.widget
 *
 * @uses ep
 * @uses de_epages
 * @since 7.5.0
 */

/**
 * Renders the widget template with the current time period.
 *
 * @method render
 * @member jQuery.ui.shopUiGreeter
 *
 * @since 7.5.0
 */

/**
 * @cfg {Array} header Array of object containing start time, end time, translation for period.
 */

/**
 * @cfg {String} subtitle Translation for the sub text.
 */

/**
 * See `jQuery.ui.shopUiGreeter for details.
 *
 * @param {Object} options A map of additional options pass to the method.
 * @param {Array} header Array of object containing start time, end time, translation for period.
 * @param {String} subtitle Translation for the sub text
 *
 * @method uiEditor
 * @member jQuery
 *
 * @since 7.5.0
 */

/*
 * @copyright       © Copyright 2006-2017, epages GmbH, All Rights Reserved.
 *
 * @module          de_epages.shop.ui.greeter
 *
 * @revision        $Revision: 1.20 $
 */
/*globals define*/
/*jslint nomen: true*/

define('de_epages/shop/ui/greeter', [
    'jquery',
    'ep',
    'de_epages',
    '$tmpl!de_epages/shop/ui/greeter',

    "jquery/ui/widget",
    "$ready!"
], function ($, ep, de_epages, tmplGreeter) {

    $.widget('ui.shopUiGreeter', {
        options: {
            header: [],
            subtitle: ''
        },

        _init: function() {
            this.render();
        },

        render: function () {
            var self = this,
                o = self.options,
                date = new Date(),
                hour = date.getHours(),
                currentTranslation = o.header.filter(function(opt) {
                    return (hour > opt.start && hour <= opt.end);
                });

            self.tmpl = tmplGreeter([{
                tHeader: (currentTranslation.length > 0) ? currentTranslation[0].translation : '',
                tSubtitle: o.subtitle
            }]);

            self.element.empty().append(self.tmpl);
        },

        destroy: function () {
            var self = this;

            self._superApply(arguments);
            self.element.empty();
        }

    });

    return de_epages;
});