define("de_epages/molliepayments/ui/mbosettings", [
    "jquery",
    "ep/ajax",
    "ep/fn/busy",
    "$ready!"
], function ($) {

        function onChangeProfileId(element) {
            mboSettingsObj.previouslySelectedMethod = mboSettingsObj.methodSelect.value;
            removeSelectOptions(mboSettingsObj.methodSelect);
            if (element.value != "-1") {
                getEnabledPaymentMethods();
            }
        }

        function onChangeTestMode(element) {
            if (mboSettingsObj.profileSelect.value == "-1") {
                return;
            }

            mboSettingsObj.previouslySelectedMethod = mboSettingsObj.methodSelect.value;
            removeSelectOptions(mboSettingsObj.methodSelect);
            getEnabledPaymentMethods();
        }

        function onClickGetProfileList(nextOrPrevious) {
            removeSelectOptions(mboSettingsObj.methodSelect);
            removeSelectOptions(mboSettingsObj.profileSelect);
            $("#NextMollieProfiles").hide();
            $("#PreviousMollieProfiles").hide();

            var fromProfileId = (nextOrPrevious == "next") ? mboSettingsObj.nextProfileId : mboSettingsObj.previousProfileId;
            getProfilesList(fromProfileId);
        }

        function onError(caller) {
            return function(errorMessage, response) {
                alert(errorMessage);
                console.log("Error by caller: " + caller);
            };
        }

        function doRequest(requestData, callbackSuccess, callbackError) {
            ep("body").busy("show");
            ep.ajax({
                "data": requestData,
                "type": "GET",
                "dataType": "json"
            }).done(function (response) {
                ep("body").busy("hide");
                callbackSuccess(response);
            }).fail(function( response ) {
                ep("body").busy("hide");
                callbackError(mboSettingsObj.errorMessages.connectionError , response);
            });
        }

        function removeSelectOptions(selectElement) {

            selectElement.value = "-1";
            selectElement.disabled = "disabled";

            for (var i = selectElement.options.length - 1; i >= 0; i--) {
                if (selectElement.options[i].value != "-1") {
                    selectElement.remove(i);
                }
            }
        }

        function getEnabledPaymentMethods() {
            var requestData = {
                "ChangeAction": "GetMolliePaymentsMethods",
                "ObjectID": mboSettingsObj.objectId,
                "ProfileId": document.getElementById("ProfileId").value,
                "IsInTestMode": document.getElementById("IsInTestMode").value
            };

            doRequest(requestData, onPaymentMethodsResponse, onError("getEnabledPaymentMethods"));
        }

        function getProfilesList(profileIdFrom) {
            var requestData = {
                "ChangeAction": "GetMolliePaymentsProfiles",
                "ObjectID": mboSettingsObj.objectId,
                "profileIdFrom": profileIdFrom ? profileIdFrom : ""
            };

            doRequest(requestData, onProfilesListResponse, onError("getProfilesList"));
        }

        function onPaymentMethodsResponse(response) {
            if (!response || typeof response.methods != "object") {
                var errorThrower = onError("onPaymentMethodsResponse");
                errorThrower(mboSettingsObj.errorMessages.unknownError, response);
                return;
            }

            addPaymentMethodsToSelect(response.methods);
        }

        function onProfilesListResponse(response) {
            if (!response || typeof response.profiles != "object") {
                var errorThrower = onError("onProfilesListResponse");
                errorThrower(mboSettingsObj.errorMessages.unknownError, response);
                return;
            }

            addProfilesToSelect(response.profiles);

            if (response.previous) {
                mboSettingsObj.previousProfileId = response.previous;
                $("#PreviousMollieProfiles").show();
            }
            if (response.next) {
                mboSettingsObj.nextProfileId = response.next;
                $("#NextMollieProfiles").show();
            }
        }

        function addPaymentMethodsToSelect(methods) {

            if (methods.length == 0) {
                return;
            }

            for (var i = 0; i < methods.length; i++) {
                var option = document.createElement("option");

                option.text = methods[i].description;
                option.value = methods[i].id;

                mboSettingsObj.methodSelect.add(option);
            }

            selectPreviousMethod();
            mboSettingsObj.methodSelect.disabled = "";
        }

        function selectPreviousMethod() {

            if (mboSettingsObj.previouslySelectedMethod == "-1") {
                return;
            }

            for (var i = 0; i < mboSettingsObj.methodSelect.options.length; i++) {
                if (mboSettingsObj.methodSelect.options[i].value == mboSettingsObj.previouslySelectedMethod) {
                    mboSettingsObj.methodSelect.options[i].selected = true;
                    break;
                }
            }
            mboSettingsObj.previouslySelectedMethod = "-1";
        }

        function addProfilesToSelect(profiles) {

            for (var i = 0; i < profiles.length; i++) {
                var option = document.createElement("option");

                option.text = profiles[i].id + " - " + profiles[i].name + " (" + profiles[i].website  +  ")";
                option.value = profiles[i].id;

                mboSettingsObj.profileSelect.add(option);
            }
            mboSettingsObj.profileSelect.disabled = "";
        }

    return function(
        profilesList,
        unknownError,
        connectionError,
        objectId
    ){
        var profileSelect = document.getElementById("ProfileId");
        var methodSelect = document.getElementById("Method");
        var previouslySelectedMethod = "-1";

        return {
            "onChangeProfileId": onChangeProfileId,
            "onChangeTestMode": onChangeTestMode,
            "onClickGetProfileList": onClickGetProfileList, 
            "profileSelect": profileSelect,
            "methodSelect": methodSelect,
            "previouslySelectedMethod": previouslySelectedMethod,
            "nextProfileId": profilesList.next,
            "previousProfileId": profilesList.previous,
            "objectId": objectId,
            "errorMessages": {
                "unknownError": unknownError,
                "connectionError": connectionError
            }
        };
    };
});
